@@ -11,7 +11,7 @@ from pyproject_migrator.result import Result
 
 def parse_args():
     ap = argparse.ArgumentParser()
-    ap.add_argument("src", nargs="*", help="Source files/directories")
+    ap.add_argument("src", nargs="+", help="Source files/directories")
     return ap.parse_args()
 
 
